# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"OLD2NEW_LABELS_DICT": "01a_constants.ipynb",
         "OLD_LABELS": "01a_constants.ipynb",
         "NEW_LABELS": "01a_constants.ipynb",
         "MAX_VALUES_BY_DTYPE_STR": "01a_constants.ipynb",
         "URL": "01a_constants.ipynb",
         "BAND_STATS": "01a_constants.ipynb",
         "BAND_STATS_FLOAT32": "01a_constants.ipynb",
         "BEN_CHANNELS": "01a_constants.ipynb",
         "BEN_10m_CHANNELS": "01a_constants.ipynb",
         "BEN_20m_CHANNELS": "01a_constants.ipynb",
         "BEN_10m_20m_CHANNELS": "01a_constants.ipynb",
         "BEN_30m_CHANNELS": "01a_constants.ipynb",
         "BEN_RGB_CHANNELS": "01a_constants.ipynb",
         "COUNTRIES": "01a_constants.ipynb",
         "COUNTRIES_ISO_A2": "01a_constants.ipynb",
         "print_all_constants": "01a_constants.ipynb",
         "USER_DIR": "01b_base.ipynb",
         "parse_datetime": "01b_base.ipynb",
         "box_from_ul_lr_coords": "01b_base.ipynb",
         "PATCHES_WITH_SNOW_URL": "01b_base.ipynb",
         "PATCHES_WITH_CLOUD_AND_SHADOW_URL": "01b_base.ipynb",
         "get_patches_with_seasonal_snow": "01b_base.ipynb",
         "get_patches_with_cloud_and_shadow": "01b_base.ipynb",
         "is_snowy_patch": "01b_base.ipynb",
         "is_cloudy_shadowy_patch": "01b_base.ipynb",
         "patches_from_original_train_split": "01b_base.ipynb",
         "patches_from_original_validation_split": "01b_base.ipynb",
         "patches_from_original_test_split": "01b_base.ipynb",
         "get_original_split_from_patch_name": "01b_base.ipynb",
         "old2new_labels": "01b_base.ipynb",
         "COUNTRIES_URL": "01c_gdf_builder.ipynb",
         "ben_patch_to_gdf": "01c_gdf_builder.ipynb",
         "ben_patch_to_reprojected_gdf": "01c_gdf_builder.ipynb",
         "build_gdf_from_patch_paths": "01c_gdf_builder.ipynb",
         "get_patch_directories": "01c_gdf_builder.ipynb",
         "get_gdf_from_patch_dir": "01c_gdf_builder.ipynb",
         "get_ben_countries_gdf": "01c_gdf_builder.ipynb",
         "assign_to_ben_country": "01c_gdf_builder.ipynb",
         "Season": "01c_gdf_builder.ipynb",
         "tfm_month_to_season": "01c_gdf_builder.ipynb",
         "filter_season": "01c_gdf_builder.ipynb",
         "add_full_ben_metadata": "01c_gdf_builder.ipynb",
         "remove_bad_ben_gdf_entries": "01c_gdf_builder.ipynb",
         "build_raw_ben_parquet": "01c_gdf_builder.ipynb",
         "extend_ben_parquet": "01c_gdf_builder.ipynb",
         "remove_discouraged_parquet_entries": "01c_gdf_builder.ipynb",
         "build_recommended_parquet": "01c_gdf_builder.ipynb",
         "recurse_link_files": "01d_subset_builder.ipynb"}

modules = ["constants.py",
           "base.py",
           "gdf_builder.py",
           "subset_builder.py"]

doc_url = "https://k.clasen.github.io/bigearthnet_common/"

git_url = "https://github.com/k.clasen/bigearthnet_common/tree/main/"

def custom_doc_links(name): return None



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/01b_base.ipynb (unless otherwise specified).

__all__ = ['USER_DIR', 'parse_datetime', 'box_from_ul_lr_coords', 'PATCHES_WITH_SNOW_URL',
           'PATCHES_WITH_CLOUD_AND_SHADOW_URL', 'get_patches_with_seasonal_snow', 'get_patches_with_cloud_and_shadow',
           'is_snowy_patch', 'is_cloudy_shadowy_patch', 'patches_from_original_train_split',
           'patches_from_original_validation_split', 'patches_from_original_test_split',
           'get_original_split_from_patch_name', 'old2new_labels']

# Cell
import functools
import urllib
import warnings
from datetime import datetime
from numbers import Real
from pathlib import Path
from typing import List, Optional, Set, Tuple, Union

import appdirs
import dateutil
import fastcore.all as fc
import geopandas
import pandas as pd
from fastcore.basics import compose
from fastcore.dispatch import typedispatch
from pydantic import AnyHttpUrl, validate_arguments
from shapely.geometry import LineString, Point, Polygon, box

from .constants import OLD2NEW_LABELS_DICT


# Cell
USER_DIR = Path(appdirs.user_data_dir("bigearthnet"))
USER_DIR.mkdir(exist_ok=True, parents=True)


# Cell
@validate_arguments
def _download_and_cache_url(url: AnyHttpUrl, force_download: bool = False):
    """
    Simply download contents of url to the default user directory.
    Allow to redownload with `force_download`
    """
    fp = USER_DIR / Path(url).name
    if not fp.exists() or force_download:
        response = urllib.request.urlopen(url).read()
        fp.write_bytes(response)
    return fp


# Cell
def parse_datetime(inp: Union[str, datetime]) -> datetime:
    """
    Parses an input into a `datetime` object.
    Will try its best to infer the correct format from a string.
    If a `datetime` object is already provided it will be returned.
    Otherwise it will raise an error.
    """
    return _parse_datetime(inp)


@typedispatch
def _parse_datetime(acquisition_date: str) -> datetime:
    return compose(dateutil.parser.parse, _parse_datetime)(acquisition_date)


@typedispatch
def _parse_datetime(acquisition_date: datetime) -> datetime:
    return acquisition_date


@typedispatch
def _parse_datetime(acquisition_date: object) -> None:
    raise TypeError("Could not parse acquisition_date!")


# Cell
def _get_box_from_two_coords(p1: Tuple[Real, Real], p2: Tuple[Real, Real]) -> Polygon:
    """
    Get the polygon that bounds the two coordinates.
    These values should be supplied as numerical values.
    """
    get_bounds = lambda geom: geom.bounds
    box_from_bounds = lambda bounds: box(*bounds)
    return compose(LineString, get_bounds, box_from_bounds)([p1, p2])


# Cell
def box_from_ul_lr_coords(ulx: Real, uly: Real, lrx: Real, lry: Real) -> Polygon:
    """
    Build a box (`Polygon`) from upper left x/y and lower right x/y coordinates.

    This specification is the default BigEarthNet style.
    """
    return _get_box_from_two_coords([ulx, uly], [lrx, lry])


# Cell
# PATCHES_WITH_SNOW_URL = "http://bigearth.net/static/documents/patches_with_seasonal_snow.csv"
# PATCHES_WITH_CLOUD_AND_SHADOW_URL = "http://bigearth.net/static/documents/get_patches_with_cloud_and_shadow.csv"
PATCHES_WITH_SNOW_URL = "https://git.tu-berlin.de/k.clasen/ben-mirror/-/raw/master/patches_with_seasonal_snow.csv"
PATCHES_WITH_CLOUD_AND_SHADOW_URL = "https://git.tu-berlin.de/k.clasen/ben-mirror/-/raw/master/patches_with_cloud_and_shadow.csv"


# Cell
@validate_arguments
def _conv_single_col_csv_to_set(
    url: AnyHttpUrl, name: str = "Name", force_download: bool = False
) -> Set:
    """
    Given a url to a CSV file *without* a header
    line and only a single column, return the set of
    all values.

    Will write remote csv to disk for better performance.
    Set `force_download` to re-download the file.
    """
    fp = _download_and_cache_url(url, force_download=force_download)
    series = pd.read_csv(
        fp,
        names=[name],
        squeeze=True,
    )
    return set(series.values)


@functools.lru_cache()
def get_patches_with_seasonal_snow(force_download: bool = False) -> Set:
    """List all patches with seasonal snow from **original** BigEarthNet dataset."""
    return _conv_single_col_csv_to_set(
        PATCHES_WITH_SNOW_URL, force_download=force_download
    )


@functools.lru_cache()
def get_patches_with_cloud_and_shadow(force_download: bool = False) -> Set:
    """List all patches with cloud and shadow from **original** BigEarthNet dataset."""
    return _conv_single_col_csv_to_set(
        PATCHES_WITH_CLOUD_AND_SHADOW_URL, force_download=force_download
    )


# Cell
@validate_arguments
def is_snowy_patch(patch_name: str):
    """
    Fast function that checks whether `patch_name` is a patch
    that contains a lot of seasonal snow.
    """
    return patch_name in get_patches_with_seasonal_snow()


@validate_arguments
def is_cloudy_shadowy_patch(patch_name: str):
    """
    Fast function that checks whether `patch_name` is a patch
    that contains a lot of shadow or is obstructed by clouds.
    """
    return patch_name in get_patches_with_cloud_and_shadow()


# Cell
@functools.lru_cache()
@validate_arguments
def patches_from_original_train_split(
    split_url: AnyHttpUrl = "https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/train.csv",
    force_download: bool = False,
) -> Set:
    """
    List all train patches from the original train/validation/test split.
    There are two possible sources:

    1. https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/train.csv
    2. https://git.tu-berlin.de/rsim/BigEarthNet-S2_43-classes_models/-/raw/master/splits/train.csv

    While writing this function, there is **no** difference between these two splits.
    But this may change in the future!
    """
    return _conv_single_col_csv_to_set(split_url, force_download=force_download)


@functools.lru_cache()
@validate_arguments
def patches_from_original_validation_split(
    split_url: AnyHttpUrl = "https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/val.csv",
    force_download: bool = False,
) -> Set:
    """
    List all validation patches from the original train/validation/test split.
    There are two possible sources:

    1. https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/train.csv"
    2. "https://git.tu-berlin.de/rsim/BigEarthNet-S2_43-classes_models/-/raw/master/splits/train.csv"

    While writing this function, there is **no** difference between these two splits.
    But this may change in the future!
    """
    return _conv_single_col_csv_to_set(split_url, force_download=force_download)


@functools.lru_cache()
@validate_arguments
def patches_from_original_test_split(
    split_url: AnyHttpUrl = "https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/test.csv",
    force_download: bool = False,
) -> Set:
    """
    List all test patches from the original train/validation/test split.
    There are two possible sources:

    1. https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/splits/test.csv
    2. https://git.tu-berlin.de/rsim/BigEarthNet-S2_43-classes_models/-/raw/master/splits/test.csv

    While writing this function, there is **no** difference between these two splits.
    But this may change in the future!
    """
    return _conv_single_col_csv_to_set(split_url, force_download=force_download)


# Cell
@validate_arguments
def get_original_split_from_patch_name(patch: str) -> Optional[str]:
    """
    Returns "train"/"validation"/"test" or `None`.
    The value is retrieved from the original BigEarthNet
    train/validation/test split. If the input is not present
    in any split, it will return `None` and raise a UserWarning.
    This happens for patches that are either in the
    cloud/shadow or seasonal snow set or if there exists no 19-label target.

    The splits are from the 19-classes version.
    While writing this function there was no difference between the
    19-classes and the 43-classes version.
    """
    train = patches_from_original_train_split()
    validation = patches_from_original_validation_split()
    test = patches_from_original_test_split()

    if patch in train:
        return "train"
    elif patch in validation:
        return "validation"
    elif patch in test:
        return "test"
    warnings.warn(
        "Provided an input patch name which was not part of the original split.",
        UserWarning,
    )
    return None


# Cell
@validate_arguments
def _old2new_label(old_label: str) -> Optional[str]:
    """
    Converts old-style BigEearthNet label to the
    new labels.

    > Note: Some labels were removed! This function
    will return `None` if the label was removed and
    raise a `KeyError` if the input label is unknown.
    """
    return OLD2NEW_LABELS_DICT[old_label]


def old2new_labels(old_labels: List[str]) -> Optional[List[str]]:
    """
    Converts a list of old-style BigEarthNet labels
    to a list of labels.

    If there are no corresponding new labels (which can happen with original BEN patches!)
    then the function will return `None` and raise a user warning.

    If an illegal/unknown input label is provided, a `KeyError` is raised.
    """
    new_labels = [
        _old2new_label(l) for l in old_labels if _old2new_label(l) is not None
    ]
    if len(old_labels) > 0 and len(new_labels) == 0:
        warnings.warn(
            "Provided a list of old labels that only contains `removed` labels!",
            UserWarning,
        )
        new_labels = None
    return new_labels



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/01d_subset_builder.ipynb (unless otherwise specified).

__all__ = ['recurse_link_files']

# Cell
import rich
from pathlib import Path
from typing import List, Optional

# Cell
def recurse_link_files(
    src_dataset, target_dir, only_suffixes: Optional[List[str]] = None
):
    """
    Copy the directory structure of `src_dataset` and
    **link** the files from the `src_dataset` to
    `target_dir`.

    This minimizes the storage-space, while allowing
    to add _local_ files.

    Optionally provide `only_suffixes` to skip all files
    that do **not** have one of the provided extensions.
    These extensions must start with `.`
    """

    for original_patch in paths:
        original_patch.resolve(strict=True)
        if original_patch.is_file():
            continue
        target_patch = target_dir / original_patch.name
        if target_patch.exists():
            rich.print(f"[yellow]Skipping: {target_patch}[/yellow]")
            continue
        target_patch.symlink_to(original_patch, target_is_directory=True)
    return str(target_dir)


# def recurse_link_files(gdf, src_dataset, target_dir):
#     paths = gdf["name"].apply(lambda name: src_dataset / name)



# AUTOGENERATED! DO NOT EDIT! File to edit: nbs/01a_constants.ipynb (unless otherwise specified).

__all__ = ['OLD2NEW_LABELS_DICT', 'OLD_LABELS', 'NEW_LABELS', 'MAX_VALUES_BY_DTYPE_STR', 'URL', 'BAND_STATS',
           'BAND_STATS_FLOAT32', 'BEN_CHANNELS', 'BEN_10m_CHANNELS', 'BEN_20m_CHANNELS', 'BEN_10m_20m_CHANNELS',
           'BEN_30m_CHANNELS', 'BEN_RGB_CHANNELS', 'COUNTRIES', 'COUNTRIES_ISO_A2', 'print_all_constants']

# Cell
import fastcore.all as fc
import natsort
import rich


# Cell


def _generate_old2new_labels_dict():
    """
    Code used to generate Old2New_labels dictionary.
    Only run once and saved the output as a constant.
    """
    import requests

    src_url = "https://git.tu-berlin.de/rsim/BigEarthNet-S2_19-classes_models/-/raw/master/label_indices.json"
    r = requests.get(src_url)
    src = r.json()
    original_labels = list(src["original_labels"].keys())
    assert len(original_labels) == 43
    new_labels = list(src["BigEarthNet-19_labels"].keys())
    assert len(new_labels) == 19
    label_conv = src["label_conversion"]
    assert len(label_conv) == len(new_labels)

    # d = {}
    # for new_label_idx, old_label_idxs in enumerate(label_conv):
    #     for old_label_idx in old_label_idxs:
    #         d[original_labels[old_label_idx]] = new_labels[new_label_idx]

    # print(d)

    old2new_label_mapping = {
        original_labels[old_idx]: new_labels[new_label_idx]
        for new_label_idx, row in enumerate(src["label_conversion"])
        for old_idx in row
    }

    deleted_labels = set(original_labels) - set(old2new_label_mapping.keys())

    for l in deleted_labels:
        old2new_label_mapping[l] = None

    assert len(old2new_label_mapping.keys()) == len(original_labels)

    return old2new_label_mapping


# Cell
OLD2NEW_LABELS_DICT = {
    "Continuous urban fabric": "Urban fabric",
    "Discontinuous urban fabric": "Urban fabric",
    "Industrial or commercial units": "Industrial or commercial units",
    "Non-irrigated arable land": "Arable land",
    "Permanently irrigated land": "Arable land",
    "Rice fields": "Arable land",
    "Vineyards": "Permanent crops",
    "Fruit trees and berry plantations": "Permanent crops",
    "Olive groves": "Permanent crops",
    "Annual crops associated with permanent crops": "Permanent crops",
    "Pastures": "Pastures",
    "Complex cultivation patterns": "Complex cultivation patterns",
    "Land principally occupied by agriculture, with significant areas of natural vegetation": "Land principally occupied by agriculture, with significant areas of natural vegetation",
    "Agro-forestry areas": "Agro-forestry areas",
    "Broad-leaved forest": "Broad-leaved forest",
    "Coniferous forest": "Coniferous forest",
    "Mixed forest": "Mixed forest",
    "Natural grassland": "Natural grassland and sparsely vegetated areas",
    "Sparsely vegetated areas": "Natural grassland and sparsely vegetated areas",
    "Moors and heathland": "Moors, heathland and sclerophyllous vegetation",
    "Sclerophyllous vegetation": "Moors, heathland and sclerophyllous vegetation",
    "Transitional woodland/shrub": "Transitional woodland, shrub",
    "Beaches, dunes, sands": "Beaches, dunes, sands",
    "Inland marshes": "Inland wetlands",
    "Peatbogs": "Inland wetlands",
    "Salt marshes": "Coastal wetlands",
    "Salines": "Coastal wetlands",
    "Water courses": "Inland waters",
    "Water bodies": "Inland waters",
    "Coastal lagoons": "Marine waters",
    "Estuaries": "Marine waters",
    "Sea and ocean": "Marine waters",
    "Airports": None,
    "Bare rock": None,
    "Dump sites": None,
    "Port areas": None,
    "Road and rail networks and associated land": None,
    "Mineral extraction sites": None,
    "Construction sites": None,
    "Sport and leisure facilities": None,
    "Burnt areas": None,
    "Intertidal flats": None,
    "Green urban areas": None,
}

OLD_LABELS = sorted(list({k for k in OLD2NEW_LABELS_DICT.keys()}))
NEW_LABELS = sorted(list({v for v in OLD2NEW_LABELS_DICT.values() if v is not None}))


# Cell
# Inspired by
# https://github.com/albumentations-team/albumentations/blob/master/albumentations/augmentations/functional.py#L1259
MAX_VALUES_BY_DTYPE_STR = {
    "uint8": 255,
    "uint16": 65535,
    "uint32": 4294967295,
    "float32": 1.0,
    "float64": 1.0,
}


# Cell
URL = "http://bigearth.net/downloads/BigEarthNet-v1.0.tar.gz"

# Stats from https://git.tu-berlin.de/rsim/bigearthnet-models-tf/-/blob/master/BigEarthNet.py
BAND_STATS = {
    "mean": {
        "B01": 340.76769064,
        "B02": 429.9430203,
        "B03": 614.21682446,
        "B04": 590.23569706,
        "B05": 950.68368468,
        "B06": 1792.46290469,
        "B07": 2075.46795189,
        "B08": 2218.94553375,
        "B8A": 2266.46036911,
        "B09": 2246.0605464,
        "B11": 1594.42694882,
        "B12": 1009.32729131,
    },
    "std": {
        "B01": 554.81258967,
        "B02": 572.41639287,
        "B03": 582.87945694,
        "B04": 675.88746967,
        "B05": 729.89827633,
        "B06": 1096.01480586,
        "B07": 1273.45393088,
        "B08": 1365.45589904,
        "B8A": 1356.13789355,
        "B09": 1302.3292881,
        "B11": 1079.19066363,
        "B12": 818.86747235,
    },
}

# FUTURE: Double check original values!
# Custom transformation to float32 values.
# Assumes that the original means and std values are encoded in uint16
BAND_STATS_FLOAT32 = {
    k: {
        band: band_val / MAX_VALUES_BY_DTYPE_STR["uint16"]
        for band, band_val in v.items()
    }
    for k, v in BAND_STATS.items()
}

BEN_CHANNELS = [
    "B01",
    "B02",
    "B03",
    "B04",
    "B05",
    "B06",
    "B07",
    "B08",
    "B8A",
    "B09",
    "B11",
    "B12",
]

BEN_10m_CHANNELS = [
    "B02",
    "B03",
    "B04",
    "B08",
]

BEN_20m_CHANNELS = [
    "B05",
    "B06",
    "B07",
    "B8A",
    "B11",
    "B12",
]

BEN_10m_20m_CHANNELS = natsort.natsorted(BEN_10m_CHANNELS + BEN_20m_CHANNELS)

BEN_30m_CHANNELS = [
    "B01",
    "B09",
]

# Correctly ordered
BEN_RGB_CHANNELS = [
    "B04",
    "B03",
    "B02",
]


# Cell
COUNTRIES = [
    "Austria",
    "Belgium",
    "Finland",
    "Ireland",
    "Kosovo",
    "Lithuania",
    "Luxembourg",
    "Portugal",
    "Serbia",
    "Switzerland",
]

# NOTE: ISO_A2 because ISO_A3 does is NOT defined for Kosovo!
COUNTRIES_ISO_A2 = [
    "AT",
    "BE",
    "FI",
    "IE",
    "XK",
    "LT",
    "LU",
    "PT",
    "RS",
    "CH",
]


# Cell


def print_all_constants():
    """
    A function that shows all of the pre-defined constants of the library.
    """
    _all = {
        k: v for k, v in globals().items() if not k.startswith("_") and k.upper() == k
    }
    rich.print(_all)


if __name__ == "__main__":
    print_all_constants()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bigearthnet_common']

package_data = \
{'': ['*']}

install_requires = \
['appdirs>=1.4,<2.0',
 'fastcore>=1.3,<2.0',
 'geopandas>=0.10,<0.11',
 'natsort>=8,<9',
 'pyarrow>=6,<7',
 'pydantic>=1.8,<2.0',
 'pygeos>=0.12,<0.13',
 'rich>=10,<11',
 'typer>=0.4,<0.5']

entry_points = \
{'console_scripts': ['ben_gdf_builder = '
                     'bigearthnet_common.gdf_builder:_run_gdf_cli']}

setup_kwargs = {
    'name': 'bigearthnet-common',
    'version': '0.1.1',
    'description': 'A collection of common tools to interact with the BigEarthNet dataset.',
    'long_description': "# Common BigEarthNet Tools\n> A personal collection of common tools to interact with the BigEarthNet dataset.\n\n\nThis library provides a collection of high-level tools to better work with the [BigEarthNet](bigearth.net) dataset.\n\n`ben_common` tries to accomplish three goals:\n\n1. Collect the most relevant _constants_ into a single place to reduce the time spent looking for these, like:\n   - The 19 or 43 class nomenclature strings\n   - URL\n   - Band statistics (mean/variance) as integer and float\n   - Channel names\n   - etc.\n2. Provide parsing functions to convert the metadata json files to a [geopandas](https://geopandas.org/en/stable/) [GeoDataFrame's](https://geopandas.org/en/stable/getting_started/introduction.html).\n   - Allow for easy top-level statistical analysis of the data in a familiar _pandas_-style \n   - Provide functions to enrich GeoDataFrames with often required BigEarthNet metadata (like the season or country of the patch)\n3. Simplify the building procedure by providing a command-line interface with reproducible results\n\n\n\n## Deep Learning \n\nOne of the main purposes of the dataset is to allow deep learning researchers and practitioners to train their model on multi-spectral satellite data easily.\nIn that regard, there is a general recommendation to drop patches that are covered by seasonal snow or clouds.\nAlso, the novel 19-class nomenclature should be preferred over the original 43-class nomenclature.\nAs a result of these recommendations, some patches have to be _excluded_ from the original raw BigEarthNet dataset that is provided at [BigEarthNet](bigearth.net).\nThis is especially important for higher-level statistical analysis.\n\nTo simplify the procedure of pre-converting the json metadata files, the library provides a single command that will generate a recommended GeoDataFrame with extra metadata (country/season data of each patch) while dropping all patches that are not recommended for deep learning research.\n\nTo generate such a GeoDataFrame and store it as an `parquet` file, use:\n\n- `gdf_builder build-recommended-parquet` (available after installing package) or\n- `python -m bigearthnet_common.gdf_builder build-recommended-parquet`\n\nIf you want to read the raw json files and convert those to a GeoDataFrame file, without dropping any patches or adding any metadata, use:\n\n- `gdf_builder build-raw-ben-parquet` (available after installing package) or\n- `python -m bigearthnet_common.gdf_builder build-raw-ben-parquet`\n\n\n## Local Installation\n\nUse [just](https://github.com/casey/just#installation) to install the package or run steps from `justfile` directly.\nRequires [mamba](https://github.com/mamba-org/mamba) (highly recommended) or [poetry](https://python-poetry.org/docs/basic-usage/) to be installed.\n\n## Local Documentation\n{% include note.html content='Building and serving the documentation requires `Docker` to be installed!' %}\nAfter creating the `ben_common_env` environment, run \n```bash\ndocker-compose up\n```\n\nOr with `just`:\n```bash\njust docs\n```\n\nAfter running the command, the documentation server will be available at \n- <http://0.0.0.0:4000/bigearthnet_common/> or \n- <http://localhost:4000/bigearthnet_common/> (WSL).\n\nTo review the source code, please look at the corresponding `ipynb` notebook from the `nbs` folder.\nThese notebooks include extensive documentation, visualizations, and tests.\nThe automatically generated Python files are available in the `bigearthnet_common` module.\n\n",
    'author': 'Kai Norman Clasen',
    'author_email': 'snakemap_navigation@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/kai-tub/bigearthnet_common',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
